/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc.utils;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.wso2.registry.ActionConstants;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.RegistryException;
import org.wso2.usermanager.Realm;
import org.wso2.usermanager.UserManagerException;
import org.wso2.usermanager.AccessControlAdmin;

public class AuthorizationUtil {

    private static final Log log = LogFactory.getLog(AuthorizationUtil.class);

    public void setDefaultAuthorizations(Realm realm, String path, String authorUserName)
            throws RegistryException {

        try {
            AccessControlAdmin accessControlAdmin = realm.getAccessControlAdmin();

            if (path.equals(RegistryConstants.ROOT_PATH)) {

                accessControlAdmin.authorizeUser(RegistryConstants.ADMIN_USER, path, ActionConstants.GET);
                accessControlAdmin.authorizeUser(RegistryConstants.ADMIN_USER, path, ActionConstants.PUT);
                accessControlAdmin.authorizeUser(RegistryConstants.ADMIN_USER, path, ActionConstants.DELETE);
                accessControlAdmin.authorizeUser(RegistryConstants.ADMIN_USER, path, ActionConstants.AUTHORIZE);

                accessControlAdmin.authorizeRole(RegistryConstants.EVERYONE_ROLE, path, ActionConstants.GET);

            } else {

                String parentPath = getParentPath(path);
                accessControlAdmin.copyAuthorizations(parentPath, path);
            }

            //accessControlAdmin.authorizeUser(RegistryConstants.ADMIN_USER, path, ActionConstants.GET);
            //accessControlAdmin.authorizeUser(RegistryConstants.ADMIN_USER, path, ActionConstants.PUT);
            //accessControlAdmin.authorizeUser(RegistryConstants.ADMIN_USER, path, ActionConstants.DELETE);
            //accessControlAdmin.authorizeUser(RegistryConstants.ADMIN_USER, path, ActionConstants.AUTHORIZE);

            //accessControlAdmin.authorizeUser(authorUserName, path, ActionConstants.GET);
            //accessControlAdmin.authorizeUser(authorUserName, path, ActionConstants.PUT);
            //accessControlAdmin.authorizeUser(authorUserName, path, ActionConstants.DELETE);
            //accessControlAdmin.authorizeUser(authorUserName, path, ActionConstants.AUTHORIZE);

        } catch (UserManagerException e) {
            String msg = "Could not default permissions. \nCaused by: " + e.getMessage();
            log.error(msg, e);
            throw new RegistryException(msg);
        }
    }

    private String getParentPath(String childPath) {

        if (childPath.equals(RegistryConstants.ROOT_PATH)) {
            return null;
        }

        int parentPathLength = childPath.lastIndexOf(RegistryConstants.PATH_SEPARATOR);

        if (parentPathLength == 0) {
            return RegistryConstants.ROOT_PATH;
        }

        String parentPath = childPath.substring(0, parentPathLength);
        return parentPath;
    }
}
